summaryrefslogtreecommitdiffstats
path: root/src/app/fullScreenAction.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/app/fullScreenAction.h')
-rw-r--r--src/app/fullScreenAction.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/app/fullScreenAction.h b/src/app/fullScreenAction.h
index 199fcfd..e86511f 100644
--- a/src/app/fullScreenAction.h
+++ b/src/app/fullScreenAction.h
@@ -1,18 +1,18 @@
// (C) 2005 Max Howell ([email protected])
// See COPYING file for licensing information
-#include <kaction.h>
+#include <tdeaction.h>
/**
* @class FullSCreenAction
* @author Max Howell <[email protected]>
* @short Adapted KToggleFullScreenAction, mainly because that class is shit
*/
-class FullScreenAction : public KToggleAction
+class FullScreenAction : public TDEToggleAction
{
public:
- FullScreenAction( TQWidget *window, KActionCollection* );
+ FullScreenAction( TQWidget *window, TDEActionCollection* );
virtual void setChecked( bool );
virtual void setEnabled( bool );
@@ -1,18 +1,18 @@
* @class FullSCreenAction
* @author Max Howell <[email protected]>
- * @short Adapted KToggleFullScreenAction, mainly because that class is shit
+ * @short Adapted TDEToggleFullScreenAction, mainly because that class is shit
*/